@@ -1,7 +1,7 @@
 /***************************************************************************
  *            GCOMObservation.hpp - COMPTEL observation class              *
  * ----------------------------------------------------------------------- *
- *  copyright (C) 2012-2024 by Juergen Knoedlseder                         *
+ *  copyright (C) 2012-2025 by Juergen Knoedlseder                         *
  * ----------------------------------------------------------------------- *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -200,13 +200,22 @@ protected:
                                 const int&     nincl  = 15,
                                 const int&     nexcl  = 0);
     GSkyMap get_weighted_drg_map(void) const;
-    void    get_bgdlixa_phibar_indices(const int& iphibar,
-                                       const int& nincl,
-                                       const int& nexcl,
-                                       int*       isel1,
-                                       int*       iex1,
-                                       int*       iex2,
-                                       int*       isel2) const;
+    void    get_bgdlix_phibar_indices(const int& iphibar,
+                                      const int& nincl,
+                                      const int& nexcl,
+                                      int*       isel1,
+                                      int*       iex1,
+                                      int*       iex2,
+                                      int*       isel2) const;
+    void    get_bgdlix_phibar_indices(const int& iphibar,
+                                      const int& nincl,
+                                      const int& nexcl,
+                                      const int& iphibar_min,
+                                      const int& iphibar_max,
+                                      int*       isel1,
+                                      int*       iex1,
+                                      int*       iex2,
+                                      int*       isel2) const;
 
     // Overwritten virtual methods
     virtual bool use_event_for_likelihood(const int& index) const;
