@@ -1,7 +1,7 @@
 /***************************************************************************
  *             GCOMObservation.cpp - COMPTEL Observation class             *
  * ----------------------------------------------------------------------- *
- *  copyright (C) 2012-2024 by Juergen Knoedlseder                         *
+ *  copyright (C) 2012-2025 by Juergen Knoedlseder                         *
  * ----------------------------------------------------------------------- *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -72,6 +72,7 @@ const GObservationRegistry g_obs_com_registry(&g_obs_com_seed);
 /* __ Macros _____________________________________________________________ */
 
 /* __ Coding definitions _________________________________________________ */
+#define G_ONLY_VALID_PHIBAR   // Include only valid Phibar range in average
 
 /* __ Debug definitions __________________________________________________ */
 
@@ -1742,7 +1743,33 @@ void GCOMObservation::compute_drb_bgdlixa(const GCOMDri& drm,
         }
     }
 
-    // Phibar normalise DRB (Equation 3.12 in Rob van Dijk's PhD thesis).
+    // Phibar normalise DRB (Equation 3.12 in Rob van Dijk's PhD thesis)
+    #if defined(G_ONLY_VALID_PHIBAR)
+    int iphibar_min = -1;
+    int iphibar_max = -1;
+    for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
+        double sum_dre = 0.0;
+        double sum_drm = 0.0;
+        double sum_drg = 0.0;
+        for (int ipix = 0; ipix < npix; ++ipix) {
+            sum_dre += map_dre(ipix, iphibar);
+            sum_drm += map_drm(ipix, iphibar);
+            sum_drg += map_drg(ipix, iphibar);
+        }
+        if (sum_drg > 0.0) {
+            double norm = (sum_dre - sum_drm) / sum_drg;
+            for (int ipix = 0; ipix < npix; ++ipix) {
+                map_dri(ipix, iphibar) = map_drg(ipix, iphibar) * norm;
+            }
+        }
+        if (sum_dre > 0.0) {
+            if (iphibar_min == -1) {
+                iphibar_min = iphibar;
+            }
+            iphibar_max = iphibar;
+        }
+    }
+    #else
     for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
         double sum_dre = 0.0;
         double sum_drm = 0.0;
@@ -1759,6 +1786,7 @@ void GCOMObservation::compute_drb_bgdlixa(const GCOMDri& drm,
             }
         }
     }
+    #endif
 
     // Do 3D running average of DRE and Phibar normalised DRG (Equation 3.13
     // in Rob van Dijk's PhD thesis). The result is a Phibar normalised DRG
@@ -1802,7 +1830,11 @@ void GCOMObservation::compute_drb_bgdlixa(const GCOMDri& drm,
                 for (int kchi = kchi_min; kchi <= kchi_max; ++kchi) {
                     for (int kpsi = kpsi_min; kpsi <= kpsi_max; ++kpsi) {
                         int kpix = kchi + kpsi * nchi;
+                        #if defined(G_ONLY_VALID_PHIBAR)
+                        for (int kphibar = iphibar_min; kphibar <= iphibar_max; ++kphibar) {
+                        #else
                         for (int kphibar = 0; kphibar < nphibar; ++kphibar) {
+                        #endif
                             if (map_drg(kpix, kphibar) != 0.0) {
                                 sum_dre += map_dre(kpix, kphibar);
                                 sum_drm += map_drm(kpix, kphibar);
@@ -1816,7 +1848,11 @@ void GCOMObservation::compute_drb_bgdlixa(const GCOMDri& drm,
                 if (sum_dri != 0.0) {
                     int    ipix = ichi + ipsi * nchi;
                     double norm = (sum_dre - sum_drm) / sum_dri;
+                    #if defined(G_ONLY_VALID_PHIBAR)
+                    for (int iphibar = iphibar_min; iphibar <= iphibar_max; ++iphibar) {
+                    #else
                     for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
+                    #endif
                         map_dri(ipix, iphibar) *= norm;
                     }
                 }
@@ -1834,11 +1870,20 @@ void GCOMObservation::compute_drb_bgdlixa(const GCOMDri& drm,
     int kex1  = 0;
     int kex2  = 0;
     int ksel2 = 0;
+    #if defined(G_ONLY_VALID_PHIBAR)
+    for (int iphibar = iphibar_min; iphibar <= iphibar_max; ++iphibar) {
+    #else
     for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
+    #endif
 
         // Get Phibar index range for sums
-        get_bgdlixa_phibar_indices(iphibar, nincl, nexcl,
-                                   &ksel1, &kex1, &kex2, &ksel2);
+        #if defined(G_ONLY_VALID_PHIBAR)
+        get_bgdlix_phibar_indices(iphibar, nincl, nexcl, iphibar_min, iphibar_max,
+                                  &ksel1, &kex1, &kex2, &ksel2);
+        #else
+        get_bgdlix_phibar_indices(iphibar, nincl, nexcl,
+                                  &ksel1, &kex1, &kex2, &ksel2);
+        #endif
 
         // Loop over Chi/Psi pixels
         for (int ipix = 0; ipix < npix; ++ipix) {
@@ -1853,14 +1898,22 @@ void GCOMObservation::compute_drb_bgdlixa(const GCOMDri& drm,
                 double sum_dri = 0.0;
 
                 // Take sum over [ksel1, kex1]
+                #if defined(G_ONLY_VALID_PHIBAR)
+                if (kex1 >= iphibar_min) {
+                #else
                 if (kex1 >= 0) {
+                #endif
                     for (int kphibar = ksel1; kphibar <= kex1; ++kphibar) {
                         sum_dri += map_dri(ipix, kphibar);
                     }
                 }
 
                 // Take sum over [kxe2, ksel2]
+                #if defined(G_ONLY_VALID_PHIBAR)
+                if (kex2 <= iphibar_max) {
+                #else
                 if (kex2 < nphibar) {
+                #endif
                     for (int kphibar = kex2; kphibar <= ksel2; ++kphibar) {
                         sum_dri += map_dri(ipix, kphibar);
                     }
@@ -1913,7 +1966,11 @@ void GCOMObservation::compute_drb_bgdlixa(const GCOMDri& drm,
             }
 
             // Loop over Phibar layers
+            #if defined(G_ONLY_VALID_PHIBAR)
+            for (int iphibar = iphibar_min; iphibar <= iphibar_max; ++iphibar) {
+            #else
             for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
+            #endif
 
                 // Initialise sums
                 double sum_dre = 0.0;
@@ -1949,11 +2006,20 @@ void GCOMObservation::compute_drb_bgdlixa(const GCOMDri& drm,
     // Third part of Equation (3.14) in Rob van Dijk's PhD thesis that sums
     // G * [E / G]^s over a subset of Phibar layers (the first parenthesis)
     // and multplies with B^0C_L / sum B^0C_L
+    #if defined(G_ONLY_VALID_PHIBAR)
+    for (int iphibar = iphibar_min; iphibar <= iphibar_max; ++iphibar) {
+    #else
     for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
+    #endif
 
         // Get Phibar index range for sums
-        get_bgdlixa_phibar_indices(iphibar, nincl, nexcl,
-                                   &ksel1, &kex1, &kex2, &ksel2);
+        #if defined(G_ONLY_VALID_PHIBAR)
+        get_bgdlix_phibar_indices(iphibar, nincl, nexcl, iphibar_min, iphibar_max,
+                                  &ksel1, &kex1, &kex2, &ksel2);
+        #else
+        get_bgdlix_phibar_indices(iphibar, nincl, nexcl,
+                                  &ksel1, &kex1, &kex2, &ksel2);
+        #endif
 
         // Loop over Chi/Psi pixels
         for (int ipix = 0; ipix < npix; ++ipix) {
@@ -1965,14 +2031,22 @@ void GCOMObservation::compute_drb_bgdlixa(const GCOMDri& drm,
                 double sum_dri = 0.0;
 
                 // Take sum over [ksel1, kex1]
+                #if defined(G_ONLY_VALID_PHIBAR)
+                if (kex1 >= iphibar_min) {
+                #else
                 if (kex1 >= 0) {
+                #endif
                     for (int kphibar = ksel1; kphibar <= kex1; ++kphibar) {
                         sum_dri += map_dri(ipix, kphibar);
                     }
                 }
 
                 // Take sum over [kxe2, ksel2]
+                #if defined(G_ONLY_VALID_PHIBAR)
+                if (kex2 <= iphibar_max) {
+                #else
                 if (kex2 < nphibar) {
+                #endif
                     for (int kphibar = kex2; kphibar <= ksel2; ++kphibar) {
                         sum_dri += map_dri(ipix, kphibar);
                     }
@@ -1988,7 +2062,11 @@ void GCOMObservation::compute_drb_bgdlixa(const GCOMDri& drm,
     } // endfor: looped over Phibar
 
     // Phibar normalise DRB
+    #if defined(G_ONLY_VALID_PHIBAR)
+    for (int iphibar = iphibar_min; iphibar <= iphibar_max; ++iphibar) {
+    #else
     for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
+    #endif
         double sum_dre = 0.0;
         double sum_drm = 0.0;
         double sum_drb = 0.0;
@@ -2011,7 +2089,11 @@ void GCOMObservation::compute_drb_bgdlixa(const GCOMDri& drm,
     }
 
     // Make sure that DRB is non-negative
+    #if defined(G_ONLY_VALID_PHIBAR)
+    for (int iphibar = iphibar_min; iphibar <= iphibar_max; ++iphibar) {
+    #else
     for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
+    #endif
         for (int ipix = 0; ipix < npix; ++ipix) {
             if (map_drb(ipix, iphibar) < 0.0) {
                 map_drb(ipix, iphibar) = 0.0;
@@ -2093,7 +2175,33 @@ void GCOMObservation::compute_drb_bgdlixe(const GCOMDri& drm,
         }
     }
 
-    // Phibar normalise DRG (Equation 3.12 in Rob van Dijk's PhD thesis).
+    // Phibar normalise DRG (Equation 3.12 in Rob van Dijk's PhD thesis)
+    #if defined(G_ONLY_VALID_PHIBAR)
+    int iphibar_min = -1;
+    int iphibar_max = -1;
+    for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
+        double sum_dre = 0.0;
+        double sum_drm = 0.0;
+        double sum_drg = 0.0;
+        for (int ipix = 0; ipix < npix; ++ipix) {
+            sum_dre += map_dre(ipix, iphibar);
+            sum_drm += map_drm(ipix, iphibar);
+            sum_drg += map_drg(ipix, iphibar);
+        }
+        if (sum_drg > 0.0) {
+            double norm = (sum_dre - sum_drm) / sum_drg;
+            for (int ipix = 0; ipix < npix; ++ipix) {
+                map_dri(ipix, iphibar) = map_drg(ipix, iphibar) * norm;
+            }
+        }
+        if (sum_dre > 0.0) {
+            if (iphibar_min == -1) {
+                iphibar_min = iphibar;
+            }
+            iphibar_max = iphibar;
+        }
+    }
+    #else
     for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
         double sum_dre = 0.0;
         double sum_drm = 0.0;
@@ -2110,6 +2218,7 @@ void GCOMObservation::compute_drb_bgdlixe(const GCOMDri& drm,
             }
         }
     }
+    #endif
 
     // Fit Phibar normalised DRG to DRE-DRM
     for (int ichi = 0; ichi < nchi; ++ichi) {
@@ -2138,15 +2247,24 @@ void GCOMObservation::compute_drb_bgdlixe(const GCOMDri& drm,
             }
 
             // Loop over Phibar layers
+            #if defined(G_ONLY_VALID_PHIBAR)
+            for (int iphibar = iphibar_min; iphibar <= iphibar_max; ++iphibar) {
+            #else
             for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
+            #endif
 
                  // Get Phibar index range for sums
                 int ksel1 = 0;
                 int kex1  = 0;
                 int kex2  = 0;
                 int ksel2 = 0;
-                get_bgdlixa_phibar_indices(iphibar, nincl, nexcl,
-                                           &ksel1, &kex1, &kex2, &ksel2);
+                #if defined(G_ONLY_VALID_PHIBAR)
+                get_bgdlix_phibar_indices(iphibar, nincl, nexcl, iphibar_min, iphibar_max,
+                                          &ksel1, &kex1, &kex2, &ksel2);
+                #else
+                get_bgdlix_phibar_indices(iphibar, nincl, nexcl,
+                                          &ksel1, &kex1, &kex2, &ksel2);
+                #endif
 
                 // Initialise sums
                 double sum_dre = 0.0;
@@ -2161,7 +2279,11 @@ void GCOMObservation::compute_drb_bgdlixe(const GCOMDri& drm,
                         int kpix = kchi + kpsi * nchi;
 
                         // Take sum over [ksel1, kex1]
+                        #if defined(G_ONLY_VALID_PHIBAR)
+                        if (kex1 >= iphibar_min) {
+                        #else
                         if (kex1 >= 0) {
+                        #endif
                             for (int kphibar = ksel1; kphibar <= kex1; ++kphibar) {
                                 sum_dre += map_dre(kpix, kphibar);
                                 sum_drm += map_drm(kpix, kphibar);
@@ -2170,7 +2292,11 @@ void GCOMObservation::compute_drb_bgdlixe(const GCOMDri& drm,
                         }
 
                         // Take sum over [kxe2, ksel2]
+                        #if defined(G_ONLY_VALID_PHIBAR)
+                        if (kex2 <= iphibar_max) {
+                        #else
                         if (kex2 < nphibar) {
+                        #endif
                             for (int kphibar = kex2; kphibar <= ksel2; ++kphibar) {
                                 sum_dre += map_dre(kpix, kphibar);
                                 sum_drm += map_drm(kpix, kphibar);
@@ -2198,7 +2324,11 @@ void GCOMObservation::compute_drb_bgdlixe(const GCOMDri& drm,
     } // endfor: looped over Chi pixels
 
     // Phibar normalise DRB
+    #if defined(G_ONLY_VALID_PHIBAR)
+    for (int iphibar = iphibar_min; iphibar <= iphibar_max; ++iphibar) {
+    #else
     for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
+    #endif
         double sum_dre = 0.0;
         double sum_drm = 0.0;
         double sum_drb = 0.0;
@@ -2221,7 +2351,11 @@ void GCOMObservation::compute_drb_bgdlixe(const GCOMDri& drm,
     }
 
     // Make sure that DRB is non-negative
+    #if defined(G_ONLY_VALID_PHIBAR)
+    for (int iphibar = iphibar_min; iphibar <= iphibar_max; ++iphibar) {
+    #else
     for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
+    #endif
         for (int ipix = 0; ipix < npix; ++ipix) {
             if (map_drb(ipix, iphibar) < 0.0) {
                 map_drb(ipix, iphibar) = 0.0;
@@ -2305,6 +2439,32 @@ void GCOMObservation::compute_drb_bgdlixf(const GCOMDri& drm,
     }
 
     // Phibar normalise DRW
+    #if defined(G_ONLY_VALID_PHIBAR)
+    int iphibar_min = -1;
+    int iphibar_max = -1;
+    for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
+        double sum_dre = 0.0;
+        double sum_drm = 0.0;
+        double sum_drw = 0.0;
+        for (int ipix = 0; ipix < npix; ++ipix) {
+            sum_dre += map_dre(ipix, iphibar);
+            sum_drm += map_drm(ipix, iphibar);
+            sum_drw += map_drw(ipix, iphibar);
+        }
+        if (sum_drw > 0.0) {
+            double norm = (sum_dre - sum_drm) / sum_drw;
+            for (int ipix = 0; ipix < npix; ++ipix) {
+                map_dri(ipix, iphibar) = map_drw(ipix, iphibar) * norm;
+            }
+        }
+        if (sum_dre > 0.0) {
+            if (iphibar_min == -1) {
+                iphibar_min = iphibar;
+            }
+            iphibar_max = iphibar;
+        }
+    }
+    #else
     for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
         double sum_dre = 0.0;
         double sum_drm = 0.0;
@@ -2321,6 +2481,7 @@ void GCOMObservation::compute_drb_bgdlixf(const GCOMDri& drm,
             }
         }
     }
+    #endif
 
     // Fit Phibar normalised DRW to DRE-DRM
     for (int ichi = 0; ichi < nchi; ++ichi) {
@@ -2349,15 +2510,24 @@ void GCOMObservation::compute_drb_bgdlixf(const GCOMDri& drm,
             }
 
             // Loop over Phibar layers
+            #if defined(G_ONLY_VALID_PHIBAR)
+            for (int iphibar = iphibar_min; iphibar <= iphibar_max; ++iphibar) {
+            #else
             for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
+            #endif
 
                  // Get Phibar index range for sums
                 int ksel1 = 0;
                 int kex1  = 0;
                 int kex2  = 0;
                 int ksel2 = 0;
-                get_bgdlixa_phibar_indices(iphibar, nincl, nexcl,
-                                           &ksel1, &kex1, &kex2, &ksel2);
+                #if defined(G_ONLY_VALID_PHIBAR)
+                get_bgdlix_phibar_indices(iphibar, nincl, nexcl, iphibar_min, iphibar_max,
+                                          &ksel1, &kex1, &kex2, &ksel2);
+                #else
+                get_bgdlix_phibar_indices(iphibar, nincl, nexcl,
+                                          &ksel1, &kex1, &kex2, &ksel2);
+                #endif
 
                 // Initialise sums
                 double sum_dre = 0.0;
@@ -2372,7 +2542,11 @@ void GCOMObservation::compute_drb_bgdlixf(const GCOMDri& drm,
                         int kpix = kchi + kpsi * nchi;
 
                         // Take sum over [ksel1, kex1]
+                        #if defined(G_ONLY_VALID_PHIBAR)
+                        if (kex1 >= iphibar_min) {
+                        #else
                         if (kex1 >= 0) {
+                        #endif
                             for (int kphibar = ksel1; kphibar <= kex1; ++kphibar) {
                                 sum_dre += map_dre(kpix, kphibar);
                                 sum_drm += map_drm(kpix, kphibar);
@@ -2381,7 +2555,11 @@ void GCOMObservation::compute_drb_bgdlixf(const GCOMDri& drm,
                         }
 
                         // Take sum over [kxe2, ksel2]
+                        #if defined(G_ONLY_VALID_PHIBAR)
+                        if (kex2 <= iphibar_max) {
+                        #else
                         if (kex2 < nphibar) {
+                        #endif
                             for (int kphibar = kex2; kphibar <= ksel2; ++kphibar) {
                                 sum_dre += map_dre(kpix, kphibar);
                                 sum_drm += map_drm(kpix, kphibar);
@@ -2409,7 +2587,11 @@ void GCOMObservation::compute_drb_bgdlixf(const GCOMDri& drm,
     } // endfor: looped over Chi pixels
 
     // Phibar normalise DRB
+    #if defined(G_ONLY_VALID_PHIBAR)
+    for (int iphibar = iphibar_min; iphibar <= iphibar_max; ++iphibar) {
+    #else
     for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
+    #endif
         double sum_dre = 0.0;
         double sum_drm = 0.0;
         double sum_drb = 0.0;
@@ -2432,7 +2614,11 @@ void GCOMObservation::compute_drb_bgdlixf(const GCOMDri& drm,
     }
 
     // Make sure that DRB is non-negative
+    #if defined(G_ONLY_VALID_PHIBAR)
+    for (int iphibar = iphibar_min; iphibar <= iphibar_max; ++iphibar) {
+    #else
     for (int iphibar = 0; iphibar < nphibar; ++iphibar) {
+    #endif
         for (int ipix = 0; ipix < npix; ++ipix) {
             if (map_drb(ipix, iphibar) < 0.0) {
                 map_drb(ipix, iphibar) = 0.0;
@@ -2476,7 +2662,7 @@ GSkyMap GCOMObservation::get_weighted_drg_map(void) const
 
 
 /***********************************************************************//**
- * @brief Compute Phibar index range for BGDLIXA background method
+ * @brief Compute Phibar index range for BGDLIX background methods
  *
  * @param[in] iphibar Phibar layer index.
  * @param[in] nincl Number of Phibar layers to include.
@@ -2486,7 +2672,7 @@ GSkyMap GCOMObservation::get_weighted_drg_map(void) const
  * @param[out] iex2 Start index for second sum.
  * @param[out] isel2 Stop index for second sum.
  *
- * This method is a helper method for the BGDLIXA background method. It
+ * This method is a helper method for the BGDLIX background methods. It
  * computes the Phibar index range for the third step of the background
  * model computation. The third step corresponds to Equation (3.14) in Rob
  * van Dijk's PhD thesis.
@@ -2494,13 +2680,13 @@ GSkyMap GCOMObservation::get_weighted_drg_map(void) const
  * The Phibar sum will be taken over the index ranges [isel1, iex1] and
  * [ixe2, isel2].
  ***************************************************************************/
-void GCOMObservation::get_bgdlixa_phibar_indices(const int& iphibar,
-                                                 const int& nincl,
-                                                 const int& nexcl,
-                                                 int*       isel1,
-                                                 int*       iex1,
-                                                 int*       iex2,
-                                                 int*       isel2) const
+void GCOMObservation::get_bgdlix_phibar_indices(const int& iphibar,
+                                                const int& nincl,
+                                                const int& nexcl,
+                                                int*       isel1,
+                                                int*       iex1,
+                                                int*       iex2,
+                                                int*       isel2) const
 {
     // Get number of Phibar layers
     int nphibar = m_drg.nphibar();
@@ -2523,7 +2709,7 @@ void GCOMObservation::get_bgdlixa_phibar_indices(const int& iphibar,
     }
 
     // Make sure that start index of first sum and stop index of second
-    // some are within the validity range
+    // sum are within the validity range
     if (*isel1 < 0) {
         *isel1 = 0;
     }
@@ -2531,14 +2717,13 @@ void GCOMObservation::get_bgdlixa_phibar_indices(const int& iphibar,
         *isel2 = imax;
     }
  
-    // Make sure that the sums use always ncincl Phibar layers, also near
+    // Make sure that the sums use always nincl Phibar layers, also near
     // the edges
     if (*isel1 == 0) {
         *isel2 = nincl - 1;
         if (nincl > imax) {
             *isel2 = imax;
         }
-
     }
     if (*isel2 == imax) {
         *isel1 = nphibar - nincl;
@@ -2552,6 +2737,84 @@ void GCOMObservation::get_bgdlixa_phibar_indices(const int& iphibar,
 }
 
 
+/***********************************************************************//**
+ * @brief Compute Phibar index range for BGDLIX background methods
+ *
+ * @param[in] iphibar Phibar layer index.
+ * @param[in] nincl Number of Phibar layers to include.
+ * @param[in] nexcl Number of Phibar layers to exclude.
+ * @param[in] iphibar_min First valid Phibar layer.
+ * @param[in] iphibar_max Last valid Phibar layer.
+ * @param[out] isel1 Start index for first sum.
+ * @param[out] iex1 Stop index for first sum.
+ * @param[out] iex2 Start index for second sum.
+ * @param[out] isel2 Stop index for second sum.
+ *
+ * This method is a helper method for the BGDLIX background methods. It
+ * computes the Phibar index range for the third step of the background
+ * model computation. The third step corresponds to Equation (3.14) in Rob
+ * van Dijk's PhD thesis. This method takes a Phibar validity range
+ * [iphibar_min, iphibar_max] on input and limits the index range to
+ * these indices.
+ *
+ * The Phibar sum will be taken over the index ranges [isel1, iex1] and
+ * [ixe2, isel2].
+ ***************************************************************************/
+void GCOMObservation::get_bgdlix_phibar_indices(const int& iphibar,
+                                                const int& nincl,
+                                                const int& nexcl,
+                                                const int& iphibar_min,
+                                                const int& iphibar_max,
+                                                int*       isel1,
+                                                int*       iex1,
+                                                int*       iex2,
+                                                int*       isel2) const
+{
+    // Precompute half running average lengths
+    int nexcl2 = int(nexcl/2);
+    int nincl2 = int(nincl/2);
+
+    // Compute Phibar index range without respecting boundaries
+    *iex1  = iphibar - nexcl2 - 1;
+    *iex2  = iphibar + nexcl2 + 1;
+    *isel1 = iphibar - nincl2;
+    *isel2 = iphibar + nincl2;
+
+    // If no Phibar layers are to be excluded then make sure that the
+    // Phibar layer range is continuous
+    if (nexcl == 0) {
+        (*iex2)--;
+    }
+
+    // Make sure that start index of first sum and stop index of second
+    // sum are within the validity range
+    if (*isel1 < iphibar_min) {
+        *isel1 = iphibar_min;
+    }
+    if (*isel2 > iphibar_max) {
+        *isel2 = iphibar_max;
+    }
+ 
+    // Make sure that the sums use always nincl Phibar layers, also near
+    // the edges
+    if (*isel1 == iphibar_min) {
+        *isel2 = nincl + iphibar_min - 1;
+        if (nincl > iphibar_max) {
+            *isel2 = iphibar_max;
+        }
+    }
+    if (*isel2 == iphibar_max) {
+        *isel1 = iphibar_max + 1 - nincl;
+        if (*isel1 < iphibar_min) {
+            *isel1 = iphibar_min;
+        }
+    }
+
+    // Return
+    return;
+}
+
+
 /***********************************************************************//**
  * @brief Check whether bin should be used for likelihood analysis
  *
