@@ -2172,6 +2172,9 @@ GVector GCOMResponse::irf_diffuse(const GModelSky&    model,
     // Initialise result
     GVector irfs(nevents);
 
+    // Get reference to normalisation parameter
+    const GModelPar& value = (*model.spatial())[0];
+
     // Initialise some variables
     double         phigeo_bin = m_phigeo_bin_size * gammalib::deg2rad;
     double         phigeo_min = m_phigeo_min      * gammalib::deg2rad - 0.5 * phigeo_bin;
@@ -2365,7 +2368,15 @@ GVector GCOMResponse::irf_diffuse(const GModelSky&    model,
 
                     // Add IRF value if it is positive
                     if (irf > 0.0) {
+
+                        // Add IRF value
                         irfs[idri] += irf;
+
+                        // Optionally set gradient
+                        if (gradients != NULL) {
+                            (*gradients)(idri,0) = (value.is_free()) ? irf * value.scale() : 0.0;
+                        }
+
                     }
 
                 } // endfor: looped over Phibar
