@@ -1,7 +1,7 @@
 /***************************************************************************
  *                       test_COM.cpp - test COM classes                   *
  * ----------------------------------------------------------------------- *
- *  copyright (C) 2012-2024 by Juergen Knoedlseder                         *
+ *  copyright (C) 2012-2025 by Juergen Knoedlseder                         *
  * ----------------------------------------------------------------------- *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -72,6 +72,8 @@ void TestGCOM::set(void)
     // Append tests to test suite
     append(static_cast<pfunction>(&TestGCOM::test_com_time),
            "GCOMSupport: Test conversion of COMPTEL time into GTime");
+    append(static_cast<pfunction>(&TestGCOM::test_com_tofcor),
+           "GCOMSupport: Test ToF correction function");
     append(static_cast<pfunction>(&TestGCOM::test_tim_class),
            "GCOMTim: Test COMPTEL Good Time Intervals");
     append(static_cast<pfunction>(&TestGCOM::test_oad_class),
@@ -86,6 +88,8 @@ void TestGCOM::set(void)
            "GCOMOad: Test COMPTEL Solar System Barycentre Data");
     append(static_cast<pfunction>(&TestGCOM::test_bvcs_class),
            "GCOMOads: Test COMPTEL Solar System Barycentre Data container");
+    append(static_cast<pfunction>(&TestGCOM::test_iaq_class),
+           "GCOMOads: Test IAQ class");
     append(static_cast<pfunction>(&TestGCOM::test_inst_dir),
            "GCOMInstDir: Test instrument direction");
     append(static_cast<pfunction>(&TestGCOM::test_event_bin),
@@ -159,6 +163,26 @@ void TestGCOM::test_com_time(void)
 }
 
 
+/***********************************************************************//**
+ * @brief Test com_tofcor function
+ ***************************************************************************/
+void TestGCOM::test_com_tofcor(void)
+{
+    // Verify ToF correction
+    double tofcor1 = gammalib::com_tofcor(GEnergy(0.8660,"MeV"),GEnergy(0.8660,"MeV"),110,130);
+    test_value(tofcor1, 1.14, "Test ToF correction value for E=0.866 MeV and ToFmin=110");
+    double tofcor2 = gammalib::com_tofcor(GEnergy(17.3205,"MeV"),GEnergy(17.3205,"MeV"),110,130);
+    test_value(tofcor2, 1.01, "Test ToF correction value for E=17.3205 MeV and ToFmin=110");
+    double tofcor3 = gammalib::com_tofcor(GEnergy(0.8660,"MeV"),GEnergy(0.8660,"MeV"),119,130);
+    test_value(tofcor3, 2.01, "Test ToF correction value for E=0.866 MeV and ToFmin=119");
+    double tofcor4 = gammalib::com_tofcor(GEnergy(17.3205,"MeV"),GEnergy(17.3205,"MeV"),119,130);
+    test_value(tofcor4, 1.67, "Test ToF correction value for E=17.3205 MeV and ToFmin=119");
+
+    // Return
+    return;
+}
+
+
 /***********************************************************************//**
  * @brief Test GCOMTim class
  ***************************************************************************/
@@ -515,6 +539,30 @@ void TestGCOM::test_bvcs_class(void)
 }
 
 
+/***********************************************************************//**
+ * @brief Test GCOMIaq class
+ ***************************************************************************/
+void TestGCOM::test_iaq_class(void)
+{
+    // Alloctate empty IAQ
+    GCOMIaq iaq1;
+
+    // Check empty IAQ
+    test_value(iaq1.image().npix(), 0, "Check that empty IAQ has no pixels");
+    test_value(iaq1.image().naxis(), 0, "Check that empty IAQ has no axes");
+
+    // Allocate IAQ
+    GCOMIaq iaq2(55.0, 1.0, 50.0, 1.0);
+
+    // Check IAQ
+    test_value(iaq2.image().npix(), 55*50, "Check that empty IAQ has pixels");
+    test_value(iaq2.image().naxis(), 2, "Check that empty IAQ has axes");
+
+    // Return
+    return;
+}
+
+
 /***********************************************************************//**
  * @brief Test GCOMInstDir class
  ***************************************************************************/
