@@ -2227,6 +2227,9 @@ GVector GSPIResponse::irf_diffuse(const GModelSky&    model,
     // Initialise result and working vector
     GVector irfs(irf.nevents);
 
+    // Get reference to normalisation parameter
+    const GModelPar& value = (*model.spatial())[0];
+
     // Loop over pointings
     for (int ipt = 0; ipt < cube->m_num_pt; ++ipt) {
 
@@ -2330,6 +2333,11 @@ GVector GSPIResponse::irf_diffuse(const GModelSky&    model,
             // Get IRF value for event
             irfs[k] = GResponse::irf_diffuse(event, source, obs);
 
+            // Optionally compute normalisation parameter gradient
+            if (gradients != NULL) {
+                (*gradients)(k,0) = (value.is_free()) ? irfs[k] * value.scale() : 0.0;
+            }
+
         } // endfor: looped over events
 
     } // endelse: used bin-wise computation
