@@ -1,7 +1,7 @@
 /***************************************************************************
  *       GModelSpatialComposite.cpp - Spatial composite model class        *
  * ----------------------------------------------------------------------- *
- *  copyright (C) 2016-2024 by Domenico Tiziani                            *
+ *  copyright (C) 2016-2025 by Domenico Tiziani                            *
  * ----------------------------------------------------------------------- *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -396,7 +396,7 @@ void GModelSpatialComposite::read(const GXmlElement& xml)
 
         // Initialise scale parameter
         GModelPar scale("", 1.0);
-        scale.range(1.0e-10, 1.0e10);
+        //scale.range(1.0e-10, 1.0e10);
         scale.fix();
 
         // Get scale value
@@ -405,6 +405,11 @@ void GModelSpatialComposite::read(const GXmlElement& xml)
             // Get scale value
             scale.value(gammalib::todouble(spec->attribute("scale")));
 
+            // If there is a "scale_error" attribute set the error accordingly
+            if (spec->has_attribute("scale_error")) {
+                scale.error(gammalib::todouble(spec->attribute("scale_error")));
+            }
+
             // If there is a "free_scale" attribute then fix or free the scaling
             // parameter accordingly
             if (spec->has_attribute("free_scale")) {
@@ -614,7 +619,7 @@ void GModelSpatialComposite::append(const GModelSpatial& component,
     // Add component name
     m_names.push_back(component_name);
 
-    // Get number of spectral parameters from model
+    // Get number of spatial parameters from model
     int npars = m_components[index]->size();
 
     // Loop over model parameters
@@ -633,7 +638,7 @@ void GModelSpatialComposite::append(const GModelSpatial& component,
 
     // Set scaling parameter
     GModelPar* scale = new GModelPar(par);
-    scale->name(component_name + ":scale");
+    scale->name(component_name + ":Scale");
     scale->scale(1.0);
     scale->gradient(0.0);
     scale->has_grad(true);
@@ -903,7 +908,7 @@ void GModelSpatialComposite::copy_members(const GModelSpatialComposite& model)
     m_scales.clear();
     m_pars.clear();
 
-    // Copy components
+    // Copy components and scales
     for (int i = 0; i < model.m_components.size(); ++i) {
 
         // Clone component
@@ -918,11 +923,6 @@ void GModelSpatialComposite::copy_members(const GModelSpatialComposite& model)
             m_pars.push_back(&par);
         }
 
-    } // endfor: looped over all components
-
-    // Copy scales
-    for (int i = 0; i < model.m_scales.size(); ++i) {
-
         // Clone scale
         GModelPar* scale = model.m_scales[i]->clone();
 
@@ -932,7 +932,7 @@ void GModelSpatialComposite::copy_members(const GModelSpatialComposite& model)
         // Push scale parameter in parameter stack
         m_pars.push_back(scale);
 
-    } // endfor: looped over scales
+    } // endfor: looped over all components
 
     // Return
     return;
