@@ -1,7 +1,7 @@
 /***************************************************************************
  *                GResponse.cpp - Abstract response base class             *
  * ----------------------------------------------------------------------- *
- *  copyright (C) 2008-2024 by Juergen Knoedlseder                         *
+ *  copyright (C) 2008-2025 by Juergen Knoedlseder                         *
  * ----------------------------------------------------------------------- *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
@@ -1451,6 +1451,9 @@ GVector GResponse::irf_diffuse(const GModelSky&    model,
     // Initialise result
     GVector irfs(nevents);
 
+    // Get reference to normalisation parameter
+    const GModelPar& value = (*model.spatial())[0];
+
     // Loop over events
     for (int k = 0; k < nevents; ++k) {
 
@@ -1467,6 +1470,11 @@ GVector GResponse::irf_diffuse(const GModelSky&    model,
         // Get IRF value for event
         irfs[k] = this->irf_diffuse(event, source, obs);
 
+        // Optionally compute normalisation parameter gradient
+        if (gradients != NULL) {
+            (*gradients)(k,0) = (value.is_free()) ? irfs[k] * value.scale() : 0.0;
+        }
+
     } // endfor: looped over events
 
     // Return IRF value
@@ -1528,31 +1536,31 @@ GVector GResponse::irf_composite(const GModelSky&    model,
         // Add IRF values
         irfs += irf * composite->scale(i)->value();
 
-        // Put spatial gradients in full matrix
-        for (int j = 0; j < spatial->size(); ++j, ++ipar) {
-            for (int k = 0; k < nevents; ++k) {
-                (*gradients)(k,ipar) = spat_gradients(k,j);
-            }
-        }
-
-        // Optionally compute scale gradient
+        // Optionally compute gradients
         if (gradients != NULL) {
 
+            // Put spatial gradients in full matrix
+            for (int j = 0; j < spatial->size(); ++j, ++ipar) {
+                for (int k = 0; k < nevents; ++k) {
+                    (*gradients)(k,ipar) = spat_gradients(k,j);
+                }
+            }
+
             // Compute normalised scale
             double scale = (composite->normalize() && sum != 0.0) ?
                             composite->scale(i)->scale() *
                             (1.0 / sum - composite->scale(i)->value() / (sum*sum)) :
                             composite->scale(i)->scale();
 
-            // Compute gradient
+            // Compute scale gradient
             for (int k = 0; k < nevents; ++k) {
-                double g = (composite->scale(i)->is_free()) ? irf[k] * scale : 0.0;
-                (*gradients)(k,ipar) = g;
+                (*gradients)(k,ipar) = (composite->scale(i)->is_free()) ? irf[k] * scale : 0.0;
             }
-        }
 
-        // Increment parameter index
-        ipar++;
+            // Increment parameter index to account for scale gradient
+            ipar++;
+
+        }
 
     } // endfor: looped over all model components
 
